Advanced Concepts — artifician Library 0.1 documentation

# Advanced Concepts

The Artifician library is designed to be easy to use for simple tasks, yet flexible enough for complex data preparation workflows. In this section, we will delve into the more advanced features and architectural choices that power the Artifician library.

## Table of Contents

- Defining Custom Extractors
  - Introduction
  - Why Custom Extractors?
  - How Extractors Work
  - Example of a Simple Extractor
  - Integrating Custom Extractors
  - Advanced Usage
  - Conclusion
- Defining Custom Processors
  - Introduction
  - Why Custom Processors?
  - How Processors Work
  - Example of a Simple Processor
  - Integrating Custom Processors
  - Advanced Usage
  - Conclusion
- Library Architecture
  - Events
  - Dataset
  - Feature Definition
  - Processors
  - Extractors

Whether you’re looking to extend the library’s capabilities or trying to get a deeper understanding of how things work, these advanced topics will provide you with the knowledge you need.